@@ -1,6 +1,6 @@
-from nctoolkit.runthis import run_this
 from nctoolkit.session import session_info
 
+
 def format(self, ext=None):
     """
     Zip the dataset
@@ -27,6 +27,6 @@ def format(self, ext=None):
 
     self._format = ext
 
-    if session_info["lazy"] == False:
+    if session_info["lazy"] is False:
         self._execute = False
         self.run()
