@@ -16,6 +16,7 @@ def add_data(self, x=None, variables=None, depths = None, nan=None, top = False)
     depths:  nctoolkit dataset or list giving depths
         If each cell has different vertical levels, this must be provided as a dataset.
         If each cell has the same vertical levels, provide it as a list.
+        If this is not supplied nctoolkit will try to figure out what they are.
         Only required if carrying out vertical matchups.
     nan: float or list
         Value or range of values to set to nan. Defaults to 0.
@@ -28,6 +29,25 @@ def add_data(self, x=None, variables=None, depths = None, nan=None, top = False)
     if depths is not None:
         self.add_depths(depths)
 
+     ##need to figure out what depths are if they are not provided.
+    if depths is None:
+        ds = open_data(x, checks = False)
+        ds = open_data(ds[0])
+        if len(ds.levels) > 1:
+            if "e3t" in ds.variables:
+                ds_depths = ds.copy()
+                ds_depths.subset(time = 0)
+                ds_depths.subset(variable = "e3t")
+                ds1 = ds_depths.copy()
+                ds_depths.vertical_cumsum()
+                ds1.run()
+                ds1.divide(2)
+                ds_depths.subtract(ds1)
+                self.depths = ds_depths.copy()
+                self.depths.rename({"e3t":"depth"})
+                print("Depths were derived from e3t variable.")
+
+
     if depths is None:
         if self.points is not None:
             if "depth" in self.points:
@@ -35,13 +55,25 @@ def add_data(self, x=None, variables=None, depths = None, nan=None, top = False)
 
     self.top = top
 
+    if variables is not None:
+        if type(variables) is str:
+            variables = [variables]
+
     if self.data is not None:
         raise ValueError("You have already added data!")
 
     if variables is None:
         print("All variables will be used")
 
-    self.data = open_data(x) 
+    self.data = open_data(x, checks = False) 
+
+    ds_vars = open_data(self.data[0])
+    ds_variables = ds_vars.variables
+
+    if type(variables) is list:
+        for x in variables:
+            if x not in ds_variables:
+                raise ValueError(f"{x} is not a valid variable")
 
     if len(self.data) > 12:
         print("Checking file times. This could take a minute")
@@ -71,7 +103,8 @@ def add_data(self, x=None, variables=None, depths = None, nan=None, top = False)
         df_times = []
 
         for ff in self.data:
-            ds = xr.open_dataset(ff)
+            ds_ff = open_data(ff)
+            ds = ds_ff.to_xarray() 
             times = ds[time_name]
             days = [int(x.dt.day) for x in times]
             months = [int(x.dt.month) for x in times]
@@ -81,11 +114,6 @@ def add_data(self, x=None, variables=None, depths = None, nan=None, top = False)
             )
         df_times = pd.concat(df_times)
 
-        if self.points is not None:
-            df_times = self.points.loc[
-                :, ["day", "month", "year"].drop(columns=self.ignore)
-            ].merge(df_times.drop(columns=self.ignore))
-
         x = list(set(df_times.path))
     self.data = open_data(x, checks = False) 
 
@@ -150,6 +178,14 @@ def add_points(self, df=None, map=None, **kwargs):
     if map is None:
         raise ValueError("Please provide a map. Starting sugestion: {'lon':'lon', 'lat':'lat', 'depth':'depth','year':'year','month':'month','day':'day'}.")
 
+    for x in map.keys():
+        if x not in ["lon", "lat", "year", "month", "day", "depth"]:
+            raise ValueError(f"{x} is not a valid mapping")
+
+    for x in map.values():
+        if x not in df.columns:
+            raise ValueError(f"{x} is not a column name")
+
     for x in ["year", "month", "day"]:
         if x in map:
             self.points_temporal = True
@@ -157,13 +193,16 @@ def add_points(self, df=None, map=None, **kwargs):
     if type(map) is not dict:
         raise ValueError("You must provided a map")
 
+    missing = []
     for x in ["year", "month", "day", "depth"]:
         if x not in map:
-            print(f"Warning: You have not provided {x} in map")
+            missing.append(x)
+    if len(missing) > 0:
+        print(f"Warning: You have not provided {missing} in dimension mapping")
 
     for x in ["lon", "lat"]:
         if x not in map:
-            raise ValueError(f"Please provide {x} in map")
+            raise ValueError(f"Please provide {x} in dimension mapping")
 
     if (
         len(
