@@ -5,7 +5,7 @@ import numpy as np
 from nctoolkit.api import open_data
 
 
-def matchup(self, on=None):
+def matchup(self, on=None, tmean = False):
     """
     Matchup gridded model and point observational data
     Parameters
@@ -15,6 +15,9 @@ def matchup(self, on=None):
         Example, if you provide ['day', 'month', 'year'] model and observational data will be matched for each day of the year across all years.
         If you provide ['month', 'year'], the matches will occur by month, and days are ignored. In this case if the model resolution is daily,
         a monthly average will be calculated automatically.
+    tmean: bool
+        Set to True or False, depending on whether you want temporal averaging at the level given by on. Defaults to False.
+        This is equivalent to doing `ds.tmean(on)` to the dataset.
 
     """
 
@@ -22,34 +25,51 @@ def matchup(self, on=None):
 
     # Figure out which points in the dataframe are actually in the dataframe...
 
-    ds = self.data.copy()
-    ds.top()
-    ds.select(variables = ds.variables[0])
-    ds.select(time = 0)
+    if on is None:
+        tmean = False
+
+    points = self.points
+
+    if type(on) is str:
+        on = [on]
+
+    if on is not None:
+        if type(on) is list:
+            for x in ["day", "month", "year"]:
+                if x not in on and x in points.columns: 
+                    points = points.drop(columns = x)
+
+
+    ds = open_data(self.data[0], checks = False)
+    ds.subset(variables = ds.variables[0])
+    ds.subset(time = 0)
     ds.rename({ds.variables[0]: "target"})
+    ds.top()
     ds.run()
     ds.assign(target = lambda x: isnan(x.target))
-    df = self.points.loc[:,["lon", "lat"]].drop_duplicates()
+    df = points.loc[:,["lon", "lat"]].drop_duplicates()
     ds.regrid(df)
-    grid = ds.to_dataframe().reset_index(drop = True).dropna().loc[:,["lon", "lat"]].drop_duplicates()
+    grid = ds.to_dataframe().reset_index().dropna().loc[:,["lon", "lat"]].drop_duplicates()
 
-    n_start = len(self.points)
+    n_start = len(points)
 
-    self.points = self.points.merge(grid)
+    points = points.merge(grid)
 
-    if len(self.points) < n_start:
-        n_remove = n_start - len(self.points)
+    if len(points) == 0:
+        raise ValueError("None of the points are contained within the dataset grid")
+
+    if len(points) < n_start:
+        n_remove = n_start - len(points)
         print(f"{n_remove} points are outside the dataset grid, and were therefore removed.")
 
+
     n_levels = len(self.data.levels)
 
     if self.points_temporal is False:
         if self.temporal:
             if on is None:
-                on = "all"
+                on = ["all"]
                 print("Points will be matched for all time steps")
-            if on is not None and on is not "all":
-                raise ValueError("No temporal information in points dataframe, so this matchup cannot occur!")
 
     if on is None:
         if self.temporal is True:
@@ -65,46 +85,48 @@ def matchup(self, on=None):
         df_times = pd.concat(df_times)
         self.data_times = df_times
 
+
     if self.temporal:
+        if on != ["all"]:
+            if on == ["day"]:
+                on = ["day", "month"]
+                if "month" not in points.columns:
+                    on.remove("month")
+            if type(on) is not list:
+                raise ValueError("on must be a list")
+            for x in on:
+                if x not in ["day", "month", "year", "all"]:
+                    raise ValueError(f"{x} is not a valid")
 
-        if type(on) is str:
-            on = [on]
+            for x in ["day", "month", "year"]:
+                if x not in on:
+                    if x in points.columns:
+                        points = points.drop(columns=x)
 
-        if on == ["day"]:
-            on = ["day", "month"]
-            if "month" not in self.points.columns:
-                on.remove("month")
-        if type(on) is not list:
-            raise ValueError("on must be a list")
-        for x in on:
-            if x not in ["day", "month", "year", "all"]:
-                raise ValueError(f"{x} is not a valid")
+            # This needs to work when there is no time
 
-        for x in ["day", "month", "year"]:
-            if x not in on:
-                if x in self.points.columns:
-                    self.points = self.points.drop(columns=x)
-
-        # This needs to work when there is no time
-
-        if self.points_temporal:
-            df_times = self.data_times.loc[:, on].merge(self.points.loc[:, on])
+            if self.points_temporal:
+                df_times = self.data_times.loc[:, on].merge(points.loc[:, on])
+            else:
+                df_times = self.data_times
+            df_times = df_times.drop_duplicates()
+            time_avail = [x for x in ["year", "month", "day"] if x in df_times.columns]
+            df_times = df_times.sort_values(by=time_avail).reset_index(drop=True)
         else:
-            df_times = self.data_times
-        df_times = df_times.drop_duplicates()
-        time_avail = [x for x in ["year", "month", "day"] if x in df_times.columns]
-        df_times = df_times.sort_values(by=time_avail).reset_index(drop=True)
+            df_times = self.data_times.drop(columns = "path")
 
     if self.temporal is False:
         df_times = self.data_times
 
+    print(df_times)
+
     df_merged = []
 
     # depths only need to be calculated once
     if self.depths is not None:
         if type(self.depths) is not list:
             ds_depths = self.depths.copy()
-            obs_locs = self.points.loc[:,["lon", "lat"]]
+            obs_locs = points.loc[:,["lon", "lat"]]
             ds_depths.regrid(obs_locs, "bil")
             df_depths = (
                 ds_depths.to_dataframe()
@@ -122,8 +144,8 @@ def matchup(self, on=None):
         if len(self.data.levels) < 2:
             ds = open_data(self.data)
             if self.variables is not None:
-                ds.select(variables = self.variables)
-            ds.regrid(self.points.loc[:,["lon", "lat"]], "bil")
+                ds.subset(variables = self.variables)
+            ds.regrid(points.loc[:,["lon", "lat"]], "bil")
             df_merged = [ds.to_dataframe().reset_index()]
             points_merged = True
 
@@ -134,19 +156,29 @@ def matchup(self, on=None):
                 i_df = df_times.iloc[
                     i : (i + 1) :,
                 ]
+                i_df = i_df.reset_index(drop = True)
                 if self.points_temporal:
-                    i_grid = self.points.merge(i_df).loc[:, ["lon", "lat"]]
+                    i_grid = points.merge(i_df).loc[:, ["lon", "lat"]]
                 else:
-                    i_grid = self.points.loc[:,["lon", "lat"]]
+                    i_grid = points.loc[:,["lon", "lat"]]
                 i_year = None
                 i_month = None
                 i_day = None
-                if "year" in on:
-                    i_year = i_df.year.values[0]
-                if "month" in on:
-                    i_month = i_df.month.values[0]
-                if "day" in on:
-                    i_day = i_df.day.values[0]
+                if "year" in on or tmean is False:
+                    try:
+                        i_year = i_df.year.values[0]
+                    except:
+                        i_year = None
+                if "month" in on or tmean is False:
+                    try:
+                        i_month = i_df.month.values[0]
+                    except:
+                        i_month = None
+                if "day" in on or tmean is False:
+                    try:
+                        i_day = i_df.day.values[0]
+                    except:
+                        i_day = None
 
                 if on == ["all"]:
                     try:
@@ -165,34 +197,33 @@ def matchup(self, on=None):
                 ds = open_data(set(self.data_times.merge(i_df).path), checks=False)
             else:
                 ds = open_data(self.data, checks=False)
-                i_grid = self.points.loc[:, ["lon", "lat"]].drop_duplicates()
+                i_grid = points.loc[:, ["lon", "lat"]].drop_duplicates()
 
 
             if self.variables is not None:
-                ds.select(variables=self.variables)
+                ds.subset(variables=self.variables)
             if self.top:
                 ds.top()
 
             if self.temporal:
                 for opt in ["day", "year", "month"]:
                     if i_day is not None:
-                        ds.select(day=i_day)
+                        ds.subset(day=i_day)
                     if i_month  is not None:
-                        ds.select(month=i_month)
+                        ds.subset(month=i_month)
                     if i_year is not None:
-                        ds.select(year=i_year)
+                        ds.subset(year=i_year)
 
                     if self.points_temporal:
                         if len(ds) > 1:
                             ds.merge("time")
-                        ds.tmean(on)
+                        #ds.tmean(on)
 
             if self.data_nan is not None:
                 ds.set_missing(self.data_nan)
 
             ds.regrid(i_grid, "bil")
 
-
             df_model = ds.to_dataframe().drop_duplicates().reset_index().drop_duplicates()
 
             # figure out the time dim
@@ -229,8 +260,6 @@ def matchup(self, on=None):
                     acceptable += [k for k in adict.keys() if adict[k]  == n_levels]
                     locs = list(set(locs))
 
-                print(locs)
-            
                 df_model = df_model.loc[
                     :,  locs
                 ].drop_duplicates()
@@ -253,9 +282,9 @@ def matchup(self, on=None):
 
 
                 if self.points_temporal:
-                    i_obs_df = i_df.merge(self.points)
+                    i_obs_df = i_df.merge(points)
                 else:
-                    i_obs_df = self.points 
+                    i_obs_df = points 
 
                 i_obs_locs = i_obs_df.loc[:, ["lon", "lat"]].drop_duplicates()
 
@@ -348,3 +377,5 @@ def matchup(self, on=None):
             df_merged = orig_df
 
     self.values = df_merged
+
+
