@@ -9,7 +9,6 @@ import multiprocessing
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
 from nctoolkit.session import (
-    nc_protected,
     session_info,
     append_safe,
     remove_safe,
@@ -19,7 +18,7 @@ from nctoolkit.temp_file import temp_file
 
 from nctoolkit.show import nc_variables
 
-from nctoolkit.utils import version_below 
+from nctoolkit.utils import version_below
 
 
 def file_size(file_path):
@@ -61,7 +60,6 @@ def tidy_command(command):
 def run_nco(command, target, out_file=None, overwrite=False):
     command = command.strip()
     append_safe(target)
-    original_target = target
     if (
         command.startswith("ncea ")
         or command.startswith("ncra ")
@@ -287,9 +285,10 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
         ):
             remove_safe(target)
             remove_safe(start_target)
-            raise ValueError(
-                str(result).replace("b'", "").replace("\\n", "").replace("'", "")
-            )
+            raise ValueError("HDF error when running CDO. Check if files are corrupt using the is_corrupt method, and consider running the check method")
+            #raise ValueError(
+            #    str(result).replace("b'", "").replace("\\n", "").replace("'", "")
+            #)
         else:
             return out_file
 
@@ -325,6 +324,9 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
             target = new_target
             append_safe(target)
 
+            if "HDF error" in str(result):
+                raise ValueError("HDF error when running CDO. Check if files are corrupt using the is_corrupt method, and consider running the check method")
+
             out = subprocess.Popen(
                 command,
                 shell=True,
@@ -468,7 +470,7 @@ def run_this(os_command, self, output="one", out_file=None):
         output = "ensemble"
 
     if len(self._hold_history) != len(self.history):
-        if self._merged == False and len(self.history) > 0 and output == "one":
+        if self._merged is False and len(self.history) > 0 and output == "one":
 
             if session_info["cdo"] in ["9.9.9"]:
                 the_command = self.history[-1].replace("cdo", "") + " "
@@ -550,7 +552,7 @@ def run_this(os_command, self, output="one", out_file=None):
                             "cdo ", f"cdo -f {self._format} "
                         )
 
-                if self._zip and zip_copy and format_it == False:
+                if self._zip and zip_copy and format_it is False:
                     ff_command = ff_command.replace("cdo ", "cdo -z zip copy ")
                 else:
                     if self._zip:
@@ -597,7 +599,7 @@ def run_this(os_command, self, output="one", out_file=None):
 
             return None
 
-        if ((output == "one") and (len(self) > 1)) or self._zip == False:
+        if ((output == "one") and (len(self) > 1)) or self._zip is False:
 
             new_history = copy.deepcopy(self._hold_history)
 
@@ -643,7 +645,7 @@ def run_this(os_command, self, output="one", out_file=None):
                 else:
                     os_command = os_command.replace("cdo ", f"cdo -f {self._format} ")
 
-            if self._zip and zip_copy and format_it == False:
+            if self._zip and zip_copy and format_it is False:
                 os_command = os_command.replace("cdo ", "cdo -z zip copy ")
             else:
                 if self._zip:
